#include <iostream>
#include <queue>
#include <deque>
#include <random>
#include <cassert>
#include <vector>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <utility>
#include <tuple>
#include <algorithm>
#include <string>
#include <iomanip>
#include <cmath>

#define int long long
#define double long double

using namespace std;

const int POW = 57;
const int MOD = 1000000009;
const double EPS = 0.0000000001;


mt19937 rnd(time(NULL));


class SegmentTree {
public:
    int n;
    vector<int> a;

    SegmentTree(int sz) {
        n = sz;
        a.resize(4 * n);
    }

    void set(int v, int vl, int vr, int i, int x) {
        if(vr - vl == 1) {
            a[v] = x;
        } else {
            int vm = (vl + vr) / 2;
            if(i < vm) {
                set(v * 2, vl, vm, i, x);
            } else {
                set(v * 2 + 1, vm, vr, i, x);
            }
            a[v] = a[v * 2] + a[v * 2 + 1];
        }
    }
    void set(int i, int x) {
        set(1, 0, n, i, x);
    }

    int get(int v, int vl, int vr, int l, int r) {
        if(l == vl && r == vr) {
            return a[v];
        }
        int vm = (vl + vr) / 2;
        if(r <= vm) {
            return get(v * 2, vl, vm, l, r);
        } else if(l >= vm) {
            return get(v * 2 + 1, vm, vr, l, r);
        } else {
            return get(v * 2, vl, vm, l, vm) + get(v * 2 + 1, vm, vr, vm, r);
        }
    }
    int get(int l, int r) {
        return get(1, 0, n, l, r);
    }
    int get(int i) {
        return get(i, i + 1);
    }
};


class Point {
public:
    double x, y;
    bool ex;

    Point(double xx, double yy) {
        x = xx;
        y = yy;
        ex = true;
    }
    Point() {
        ex = false;
    }

    operator bool() {
        return ex;
    }
};


class Vector {
public:
    double x, y;

    Vector(double xx, double yy) {
        x = xx;
        y = yy;
    }
    Vector(Point a, Point b) {
        x = b.x - a.x;
        y = b.y - a.y;
    }

    double operator* (Vector v) {
        return x * v.x + y * v.y;
    }
    double operator% (Vector v) {
        return x * v.y - y * v.x;
    }

    Vector operator+ (Vector v) {
        return Vector(x + v.x, y + v.y);
    }
    Vector operator- (Vector v) {
        return Vector(x - v.x, y - v.y);
    }
    Vector operator- () {
        return Vector(-x, -y);
    }
    Vector operator* (double coeff) {
        return Vector(x * coeff, y * coeff);
    }
    Vector operator/ (double coeff) {
        return Vector(x / coeff, y / coeff);
    }
};

Point operator+ (Point p, Vector v) {
    return Point(p.x + v.x, p.y + v.y);
}


class Line {
public:
    double a, b, c;

    Line(double aa, double bb, double cc) {
        a = aa;
        b = bb;
        c = cc;
    }

    Line(Point p1, Point p2) {
        a = p1.y - p2.y;
        b = p2.x - p1.x;
        c = -a * p1.x - b * p1.y;
        double coeff = sqrt(a * a + b * b);
        a /= coeff;
        b /= coeff;
        c /= coeff;
    }

    double operator() (Point p) {
        return a * p.x + b * p.y + c;
    }

    bool contains(Point p) {
        return abs((*this)(p)) < EPS;
    }

    Point operator& (Line l) {
        if(abs(b * l.a - l.b * a) < EPS) {
            return Point();
        }
        double x = (l.b * c - b * l.c) / (b * l.a - l.b * a);
        double y = (l.a * c - a * l.c) / (a * l.b - l.a * b);
        return Point(x, y);
    }
};


class Segment {
public:
    Point a, b;

    Segment(Point aa, Point bb) {
        a = aa;
        b = bb;
    }


    Point operator& (Segment s) {
        Point p = Line(a, b) & Line(s.a, s.b);
        if(!p) {
            return Point();
        }
        if(
           min(a.x, b.x) - EPS < p.x && p.x < max(a.x, b.x) + EPS &&
           min(a.y, b.y) - EPS < p.y && p.y < max(a.y, b.y) + EPS &&
           min(s.a.x, s.b.x) - EPS < p.x && p.x < max(s.a.x, s.b.x) + EPS &&
           min(s.a.y, s.b.y) - EPS < p.y && p.y < max(s.a.y, s.b.y) + EPS
        ) {
            return p;
        }
        return Point();
    }
};


class Vertex {
public:
    int sz;
    int y;
    int val;
    Vertex* left;
    Vertex* right;

    Vertex(int value) {
        sz = 1;
        y = rnd();
        val = value;
        left = nullptr;
        right = nullptr;
    }

    ~Vertex() {
        if(left) {
            delete left;
        }
        if(right) {
            delete right;
        }
    }

    void pull() {
        sz = (left ? left->sz : 0) + 1 + (right ? right->sz : 0);
    }
};


class Treap {
public:
    Vertex* root;

    Treap() {
        root = nullptr;
    }

    Vertex* merge(Vertex* a, Vertex* b) {
        if(a == nullptr) {
            return b;
        } else if(b == nullptr) {
            return a;
        }
        if(a->y > b->y) {
            a->right = merge(a->right, b);
            a->pull();
            return a;
        } else {
            b->left = merge(a, b->left);
            b->pull();
            return b;
        }
    }

    pair<Vertex*, Vertex*> split(Vertex* v, int pos) {
        if(v == nullptr) {
            return make_pair(nullptr, nullptr);
        }
        if((v->left ? v->left->sz : 0) >= pos) {
            pair<Vertex*, Vertex*> p = split(v->left, pos);
            v->left = p.second;
            v->pull();
            return make_pair(p.first, v);
        } else {
            pair<Vertex*, Vertex*> p = split(v->right, pos - (v->left ? v->left->sz : 0) - 1);
            v->right = p.first;
            v->pull();
            return make_pair(v, p.second);
        }
    }

    int size() {
        return root ? root->sz : 0;
    }

    void insert(int pos, int val) {
        pair<Vertex*, Vertex*> p = split(root, pos);
        root = merge(p.first, merge(new Vertex(val), p.second));
    }

    void erase(int pos) {
        pair<Vertex*, Vertex*> p = split(root, pos);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        root = merge(p.first, p2.second);
        delete p2.first;
    }

    int get(int pos) {
        pair<Vertex*, Vertex*> p = split(root, pos);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        assert(p2.first != nullptr);
        int val = p2.first->val;
        root = merge(p.first, merge(p2.first, p2.second));
        return val;
    }
};


int readint() {
    int num = 0;
    char c;
    do {
        c = fgetc(stdin);
    } while(!('0' <= c && c <= '9'));
    do {
        num = (num * 10) + (c - '0');
        c = fgetc(stdin);
    } while('0' <= c && c <= '9');
    return num;
}


template<class T1, class T2> struct std::hash< pair<T1, T2> > {
    size_t operator() (pair<T1, T2> arg) const {
        return std::hash<T1>{}(arg.first) * 57 + std::hash<T2>{}(arg.second) * 179;
    }
};


int gcd(int a, int b) {
    while(a != 0 && b != 0) {
        a %= b;
        swap(a, b);
    }
    return a + b;
}


signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    int a, b;
    cin >> a >> b;

    if(a == b) {
        cout << 0;
        return 0;
    }

    if(a < b) {
        swap(a, b);
    }

    int alpha = a / gcd(a, b);
    int beta = b / gcd(a, b);

    int ans = 0;
    for(int a1 = 0; a1 <= a; a1++) {
        for(int b1 = 0; b1 <= b; b1++) {
            if(a1 * b == b1 * a || b1 * b == a1 * a) {
                continue;
            }
            if((a - a1) * alpha != (b - b1) * beta) {
                continue;
            }
            int x = a - a1;
            int y = b - b1;
            if(x <= alpha || y <= beta) {
                ans++;
            }
        }
    }

    cout << ans;

    return 0;
}
