#include <iostream>
#include <queue>
#include <deque>
#include <random>
#include <cassert>
#include <vector>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <utility>
#include <tuple>
#include <algorithm>
#include <string>
#include <iomanip>
#include <cmath>

#define int long long
#define double long double

using namespace std;

const int POW = 57;
const int MOD = 1000000009;
const double EPS = 0.0000000001;


mt19937 rnd(time(NULL));


class SegmentTree {
public:
    int n;
    vector<int> a;

    SegmentTree(int sz) {
        n = sz;
        a.resize(4 * n);
    }

    void set(int v, int vl, int vr, int i, int x) {
        if(vr - vl == 1) {
            a[v] = x;
        } else {
            int vm = (vl + vr) / 2;
            if(i < vm) {
                set(v * 2, vl, vm, i, x);
            } else {
                set(v * 2 + 1, vm, vr, i, x);
            }
            a[v] = a[v * 2] + a[v * 2 + 1];
        }
    }
    void set(int i, int x) {
        set(1, 0, n, i, x);
    }

    int get(int v, int vl, int vr, int l, int r) {
        if(l == vl && r == vr) {
            return a[v];
        }
        int vm = (vl + vr) / 2;
        if(r <= vm) {
            return get(v * 2, vl, vm, l, r);
        } else if(l >= vm) {
            return get(v * 2 + 1, vm, vr, l, r);
        } else {
            return get(v * 2, vl, vm, l, vm) + get(v * 2 + 1, vm, vr, vm, r);
        }
    }
    int get(int l, int r) {
        return get(1, 0, n, l, r);
    }
    int get(int i) {
        return get(i, i + 1);
    }
};


class Point {
public:
    double x, y;
    bool ex;

    Point(double xx, double yy) {
        x = xx;
        y = yy;
        ex = true;
    }
    Point() {
        ex = false;
    }

    operator bool() {
        return ex;
    }
};


class Vector {
public:
    double x, y;

    Vector(double xx, double yy) {
        x = xx;
        y = yy;
    }
    Vector(Point a, Point b) {
        x = b.x - a.x;
        y = b.y - a.y;
    }

    double operator* (Vector v) {
        return x * v.x + y * v.y;
    }
    double operator% (Vector v) {
        return x * v.y - y * v.x;
    }

    Vector operator+ (Vector v) {
        return Vector(x + v.x, y + v.y);
    }
    Vector operator- (Vector v) {
        return Vector(x - v.x, y - v.y);
    }
    Vector operator- () {
        return Vector(-x, -y);
    }
    Vector operator* (double coeff) {
        return Vector(x * coeff, y * coeff);
    }
    Vector operator/ (double coeff) {
        return Vector(x / coeff, y / coeff);
    }
};

Point operator+ (Point p, Vector v) {
    return Point(p.x + v.x, p.y + v.y);
}


class Line {
public:
    double a, b, c;

    Line(double aa, double bb, double cc) {
        a = aa;
        b = bb;
        c = cc;
    }

    Line(Point p1, Point p2) {
        a = p1.y - p2.y;
        b = p2.x - p1.x;
        c = -a * p1.x - b * p1.y;
        double coeff = sqrt(a * a + b * b);
        a /= coeff;
        b /= coeff;
        c /= coeff;
    }

    double operator() (Point p) {
        return a * p.x + b * p.y + c;
    }

    bool contains(Point p) {
        return abs((*this)(p)) < EPS;
    }

    Point operator& (Line l) {
        if(abs(b * l.a - l.b * a) < EPS) {
            return Point();
        }
        double x = (l.b * c - b * l.c) / (b * l.a - l.b * a);
        double y = (l.a * c - a * l.c) / (a * l.b - l.a * b);
        return Point(x, y);
    }
};


class Segment {
public:
    Point a, b;

    Segment(Point aa, Point bb) {
        a = aa;
        b = bb;
    }


    Point operator& (Segment s) {
        Point p = Line(a, b) & Line(s.a, s.b);
        if(!p) {
            return Point();
        }
        if(
           min(a.x, b.x) - EPS < p.x && p.x < max(a.x, b.x) + EPS &&
           min(a.y, b.y) - EPS < p.y && p.y < max(a.y, b.y) + EPS &&
           min(s.a.x, s.b.x) - EPS < p.x && p.x < max(s.a.x, s.b.x) + EPS &&
           min(s.a.y, s.b.y) - EPS < p.y && p.y < max(s.a.y, s.b.y) + EPS
        ) {
            return p;
        }
        return Point();
    }
};


class Vertex {
public:
    int sz;
    int y;
    int val;
    Vertex* left;
    Vertex* right;

    Vertex(int value) {
        sz = 1;
        y = rnd();
        val = value;
        left = nullptr;
        right = nullptr;
    }

    ~Vertex() {
        if(left) {
            delete left;
        }
        if(right) {
            delete right;
        }
    }

    void pull() {
        sz = (left ? left->sz : 0) + 1 + (right ? right->sz : 0);
    }
};


class Treap {
public:
    Vertex* root;

    Treap() {
        root = nullptr;
    }

    Vertex* merge(Vertex* a, Vertex* b) {
        if(a == nullptr) {
            return b;
        } else if(b == nullptr) {
            return a;
        }
        if(a->y > b->y) {
            a->right = merge(a->right, b);
            a->pull();
            return a;
        } else {
            b->left = merge(a, b->left);
            b->pull();
            return b;
        }
    }

    pair<Vertex*, Vertex*> split(Vertex* v, int pos) {
        if(v == nullptr) {
            return make_pair(nullptr, nullptr);
        }
        if((v->left ? v->left->sz : 0) >= pos) {
            pair<Vertex*, Vertex*> p = split(v->left, pos);
            v->left = p.second;
            v->pull();
            return make_pair(p.first, v);
        } else {
            pair<Vertex*, Vertex*> p = split(v->right, pos - (v->left ? v->left->sz : 0) - 1);
            v->right = p.first;
            v->pull();
            return make_pair(v, p.second);
        }
    }

    int size() {
        return root ? root->sz : 0;
    }

    void insert(int pos, int val) {
        pair<Vertex*, Vertex*> p = split(root, pos);
        root = merge(p.first, merge(new Vertex(val), p.second));
    }

    void erase(int pos) {
        pair<Vertex*, Vertex*> p = split(root, pos);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        root = merge(p.first, p2.second);
        delete p2.first;
    }

    int get(int pos) {
        pair<Vertex*, Vertex*> p = split(root, pos);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        assert(p2.first != nullptr);
        int val = p2.first->val;
        root = merge(p.first, merge(p2.first, p2.second));
        return val;
    }
};


int readint() {
    int num = 0;
    char c;
    do {
        c = fgetc(stdin);
    } while(!('0' <= c && c <= '9'));
    do {
        num = (num * 10) + (c - '0');
        c = fgetc(stdin);
    } while('0' <= c && c <= '9');
    return num;
}


template<class T1, class T2> struct std::hash< pair<T1, T2> > {
    size_t operator() (pair<T1, T2> arg) const {
        return std::hash<T1>{}(arg.first) * 57 + std::hash<T2>{}(arg.second) * 179;
    }
};


const int BIGINT_POWER = 6;
const int BIGINT_BASE = 1000000;

class BigInt {
public:
    vector<int> a;
    bool is_negative;

    BigInt() {
        is_negative = false;
    }

    BigInt(int num) {
        is_negative = num < 0;
        num = abs(num);
        while(num) {
            a.push_back(num % BIGINT_BASE);
            num /= BIGINT_BASE;
        }
    }

    BigInt operator+ (BigInt other) {
        if(other.is_negative) {
            other.is_negative = false;
            return (*this) - other;
        } else if(is_negative) {
            return other + (*this);
        }
        BigInt res(*this);
        res.a.resize(max(a.size(), other.a.size()));
        int carry = 0;
        for(int i = 0; i < other.a.size(); i++) {
            res.a[i] += carry + other.a[i];
            carry = res.a[i] / BIGINT_BASE;
            res.a[i] %= BIGINT_BASE;
        }
        if(carry) {
            res.a.push_back(carry);
        }
        return res;
    }

    BigInt operator- (BigInt other) {
        if(other.is_negative) {
            other.is_negative = false;
            return (*this) + other;
        } else if(is_negative) {
            return -(other - (*this));
        } else if(*this < other) {
            return -(other - (*this));
        }
        BigInt res(*this);
        int carry = 0;
        for(int i = 0; i < other.a.size(); i++) {
            res.a[i] -= carry + other.a[i];
            carry = 0;
            if(res.a[i] < 0) {
                res.a[i] += BIGINT_BASE;
                carry = 1;
            }
        }
        while(res.a.size() > 0 && res.a.back() == 0) {
            res.a.pop_back();
        }
        return res;
    }

    BigInt operator- () const {
        BigInt res = *this;
        if(res.a.size() > 0) {
            res.is_negative = !res.is_negative;
        }
        return res;
    }

    bool operator< (const BigInt other) const {
        if(is_negative && other.is_negative) {
            return -(*this) > -other;
        } else if(is_negative) {
            return true;
        } else if(other.is_negative) {
            return false;
        } else if(a.size() < other.a.size()) {
            return true;
        } else if(a.size() > other.a.size()) {
            return false;
        } else {
            for(int i = (int)a.size() - 1; i >= 0; i--) {
                if(a[i] < other.a[i]) {
                    return true;
                } else if(a[i] > other.a[i]) {
                    return false;
                }
            }
            return false;
        }
    }
    bool operator> (const BigInt other) const {
        return other < (*this);
    }
    bool operator<= (const BigInt other) const{
        return !((*this) > other);
    }
    bool operator>= (const BigInt other) const{
        return !((*this) < other);
    }
    bool operator== (const BigInt other) const {
        return is_negative == other.is_negative && a == other.a;
    }
    bool operator!= (const BigInt other) const {
        return !((*this) == other);
    }

    BigInt operator* (BigInt other) {
        BigInt res;
        res.a.resize(a.size() + other.a.size() + 1);

        for(int i = 0; i < a.size(); i++) {
            for(int j = 0; j < other.a.size(); j++) {
                res.a[i + j] += a[i] * other.a[j];
                res.a[i + j + 1] += res.a[i + j] / BIGINT_BASE;
                res.a[i + j] %= BIGINT_BASE;
            }
        }

        int carry = 0;
        for(int i = 0; i < res.a.size(); i++) {
            res.a[i] += carry;
            carry = res.a[i] / BIGINT_BASE;
            res.a[i] %= BIGINT_BASE;
        }
        while(carry > 0) {
            res.a.push_back(carry % BIGINT_BASE);
            carry /= BIGINT_BASE;
        }

        while(res.a.size() > 0 && res.a.back() == 0) {
            res.a.pop_back();
        }

        if(res.a.size() > 0) {
            res.is_negative = is_negative != other.is_negative;
        }

        return res;
    }

    BigInt operator/ (int other) {
        bool is_negative_other = other < 0;
        other = abs(other);

        BigInt res;

        int carry = 0;
        for(int i = a.size() - 1; i >= 0; i--) {
            res.a.push_back((carry * BIGINT_BASE + a[i]) / other);
            carry = (carry * BIGINT_BASE + a[i]) % other;
        }
        reverse(res.a.begin(), res.a.end());

        while(res.a.size() > 0 && res.a.back() == 0) {
            res.a.pop_back();
        }

        if(res.a.size() > 0) {
            res.is_negative = is_negative != is_negative_other;
        }

        return res;
    }

    BigInt operator/ (BigInt other) const {
        bool is_negative_res = is_negative != other.is_negative;
        other.is_negative = false;

        BigInt abs_val = *this;
        abs_val.is_negative = false;

        BigInt l;
        BigInt r = abs_val + (BigInt)1;
        while(r - l > 1) {
            BigInt m = (l + r) / 2;
            if(m * other > abs_val) {
                r = m;
            } else {
                l = m;
            }
        }

        if(l.a.size() > 0) {
            l.is_negative = is_negative_res;
        }

        return l;
    }

    BigInt operator% (BigInt other) {
        return (*this) - (*this) / other * other;
    }


    BigInt& operator+= (BigInt other) {
        return *this = *this + other;
    }
    BigInt& operator-= (BigInt other) {
        return *this = *this - other;
    }
    BigInt& operator*= (BigInt other) {
        return *this = *this * other;
    }
    BigInt& operator/= (int other) {
        return *this = *this / other;
    }
    BigInt& operator/= (BigInt other) {
        return *this = *this / other;
    }
    BigInt& operator%= (BigInt other) {
        return *this = *this % other;
    }


    friend ostream& operator<< (ostream& out, const BigInt& val) {
        if(val.a.size() == 0) {
            out << 0;
        } else {
            if(val.is_negative) {
                cout << "-";
            }
            out << val.a.back();
            for(int i = (int)val.a.size() - 2; i >= 0; i--) {
                int part = val.a[i];
                string st;
                while(part > 0) {
                    st.push_back('0' + part % 10);
                    part /= 10;
                }
                reverse(st.begin(), st.end());
                out << string(BIGINT_POWER - st.size(), '0') << st;
            }
        }
        return out;
    }
};


BigInt gcd(BigInt a, BigInt b) {
    while(a != 0 && b != 0) {
        a %= b;
        swap(a, b);
    }
    return a + b;
}


signed main() {
    assert(BigInt(0) == BigInt(0));
    assert(BigInt(72) == BigInt(72));
    assert(BigInt(73) != BigInt(-73));
    assert(BigInt(14) != BigInt(41));
    assert(BigInt(71) > BigInt(-71));
    assert(BigInt(19) < BigInt(23));
    assert(BigInt(13) + BigInt(25) == BigInt(38));
    assert(BigInt(38) - BigInt(13) == BigInt(25));
    assert(BigInt(13) - BigInt(38) == BigInt(-25));
    assert(-BigInt(156) == BigInt(-156));
    assert(BigInt(38) - BigInt(-25) == BigInt(63));
    assert(BigInt(-33) < BigInt(22));
    assert(BigInt(-33) * BigInt(-22) == BigInt(726));
    assert(BigInt(-33) * BigInt(22) == BigInt(-726));
    assert(BigInt(-33) / BigInt(22) == BigInt(-1));
    assert(BigInt(-4400) / BigInt(22) == BigInt(-200));
    assert(BigInt(-4400) / BigInt(-22) == BigInt(200));
    assert(BigInt(50) / BigInt(25) == BigInt(2));
    assert(BigInt(95) % BigInt(32) == BigInt(31));
    assert(BigInt(-95) % BigInt(32) == BigInt(-31));
    assert(BigInt(-84) % BigInt(4) == BigInt(0));


    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    BigInt a, b;
    int a1, b1;
    cin >> a1 >> b1;
    a = a1;
    b = b1;

    if(a == b) {
        cout << 0;
        return 0;
    }

    if(a < b) {
        swap(a, b);
    }

    BigInt alpha = a / gcd(a, b);
    BigInt beta = b / gcd(a, b);

    BigInt ans = (b + 1) * alpha;

    BigInt l2 = (b - beta + 1) * a / b;
    BigInt r2 = a - alpha;
    if(l2 <= r2) {
        ans -= r2 / alpha - (l2 - 1) / alpha;
    }

    BigInt l = alpha;
    BigInt r = a - max((BigInt)0, a + b * ((BigInt)1 - beta) / a);
    if(l <= r) {
        ans += r / beta - (l - 1) / beta;
    }

    BigInt l1 = ((b - beta + 1) * alpha + beta - 1) / beta;
    BigInt r1 = min(a - alpha, b / beta * alpha);
    if(l1 <= r1) {
        ans += r1 / alpha - (l1 - 1) % alpha;

        BigInt r = a * a - b * b;
        BigInt l = a - beta / alpha * b;
        if(r % l == 0) {
            ans += r1 / alpha - (l1 - 1) / alpha;
            if(r / l % alpha == 0) {
                if(l1 <= r / l && r / l <= r1) {
                    ans += (BigInt)1;
                }
            }
        }
    }

    ans -= (b + 1) * alpha;
    ans += min(b * b / a, alpha - (BigInt)1) / beta;

    cout << ans;

    return 0;
}
